#include "RNP2to191.h"

namespace rnp2to191 {

	inline double sqr( double v ){
			return  v * v;
	}

    //        Standard Normal Distribution
	//        Rejection polar method for normal variate
	double RNP2to191::normal(){
		double v1, v2, w;
		do {
    		v1 = 2.0 * uni() - 1.0;
			v2 = 2.0 * uni() - 1.0;
			w  = sqr(v1) + sqr(v2);
		} while (((w >= 1.0) || (w <= 0.0)));
		
		double c = sqrt(-2.0 * log(w)/w);

		return c * v1;
	}


    //    Normal Distribution of mean m  and standard deviation s
	double RNP2to191::normalMS(double m, double s){
			double v = s * normal() + m;
			return  v;
	}


    //    A Pair of Independent Random Numbers of 
	//      the Standard Normal Distribution 
	void  RNP2to191::normalPair( double & n1, double & n2 ){
			double v1, v2, w, c;
			do {
				  v1 = 2.0 * uni() - 1.0;
				  v2 = 2.0 * uni() - 1.0;
				  w  = sqr(v1) + sqr(v2);
			} while (((w >= 1.0) || (w <= 0.0)));

			c = sqrt(-2.0 * log(w) / w);

			n1 = c * v1;
			n2 = c * v2;
	}


}
